@@ -1,10 +1,12 @@
 from pathlib import Path
+from typing import Tuple, Callable
+from xlsxwriter.format import Format
 
 import pandas as pd
 import xlsxwriter
 
 
-class RexelWorkbook:
+class RexcelWorkbook:
     COLS = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
 
     def __init__(
@@ -26,9 +28,11 @@ class RexelWorkbook:
             df: pd.DataFrame,
             worksheet_name: str,
             column_widths: list,
-            include_index: bool = False
+            include_index: bool = False,
+            format_rows: Tuple[Callable, Format] = None
     ):
         df = df.where(pd.notnull(df), '')
+        format_test, row_format = format_rows if format_rows else (None, None)
         if include_index:
             df = df.reset_index()
         wks = self.workbook.add_worksheet(name=worksheet_name)
@@ -37,7 +41,7 @@ class RexelWorkbook:
             for first, last, width in column_widths:
                 wks.set_column(first, last, width)
         for j, header in enumerate(df.columns):
-            if not header:
+            if not header or header == 'index':
                 continue
             wks.write(
                 f"{self.COLS[j]}1",
@@ -57,11 +61,16 @@ class RexelWorkbook:
             for j, cell in enumerate(row):
                 if type(cell) not in write_funcs:
                     cell = str(cell)
-                write_func = write_funcs.get(type(cell))
-                write_func(
+                cell_info = [
                     row_number,
                     col_number + offset,
                     cell
+                ]
+                if format_rows is not None and format_test(row_number):
+                    cell_info.append(row_format)
+                write_func = write_funcs.get(type(cell))
+                write_func(
+                    *cell_info
                 )
                 offset += 1
             row_number += 1
